@@ -1,6 +1,6 @@
 import click
 
-from .commands import start_dash, start_project
+from .commands import generate_assets_cmd, start_dash, start_project
 
 
 @click.group()
@@ -10,6 +10,7 @@ def cli():
 
 cli.add_command(start_project)
 cli.add_command(start_dash)
+cli.add_command(generate_assets_cmd)
 
 if __name__ == "__main__":
     cli()  # pragma: no cover
